Learn R Programming

matchingMarkets (version 0.1-1)

matchingMarkets-package: An R package for the analysis of stable matchings.

Description

The matchingMarkets package contains Rand C++ code for the estimation of structural models that correct for the sample selection bias of observed outcomes in matching markets.

Matching is concerned with who transacts with whom, and how. For example, who works at which job, which students go to which school, who forms a workgroup with whom, and so on.

The empirical analysis of matching markets is naturally subject to sample selection problems. If agents match assortatively on characteristics unobserved to the analyst but correlated with both the exogenous variable and the outcome of interest, regression estimates will generally be biased.

The matchingMarkets package comprises

  1. Bayes estimators. The estimators implemented in functionstabitcorrect for the selection bias from endogenous matching.

The current package version provides solutions for two commonly observed matching processes: (i) thegroup formation problemwith fixed group sizes and (ii) theroommates problemwith transferable utility. Work on (iii) the college admissions problem is still in progress. These processes determine which matches are observed -- and which are not -- and this is a sample selection problem.

  • Post-estimation tools. Functionmfxcomputes marginal effects from coefficients in binary outcome and selection equations andkhbimplements the Karlson-Holm-Breen test for confounding due to sample selection.
  • Design matrix generation. The estimators are based on independent variables for all feasible, i.e., observed and counterfactual, matches in the market. Generating the characteristics of all feasible matches from individual-level data is a combinatorial problem. Thestabitfunction has an argumentmethod="model.frame"that returns a design matrix based on pre-specified transformations to generate counterfactual matches.
  • Algorithms. The package also contains several matching algorithms such as the deferred acceptance algorithm (daa) forhttp://en.wikipedia.org/wiki/Stable_matching{stable marriages} andhttp://en.wikipedia.org/wiki/Hospital_resident{college admissions}, the top-trading-cycles algorithm (ttc) forhttp://en.wikipedia.org/wiki/Herbert_Scarf#8._The_Housing_Market{house allocation} and a partioning linear program (plp) for thehttp://en.wikipedia.org/wiki/Stable_roommates_problem{stable roommates problem}. These can be used to obtain stable matchings from simulated or real preference data.
  • Data. In addition to thebaac00dataset from borrowing groups in Thailands largest agricultural lending program, the package provides functions to simulate one's own data from matching markets.stabsimgenerates individual-level data and thestabitfunction has an argumentsimulationwhich generates group-level data and determines which groups are observed in equilibrium based on an underlying linear stochastic model.
  • Arguments

    Frequently Asked Questions

    • Why can I not use the classic Heckman correction?Estimators such as the Heckman (1979) correction (in packagehttp://cran.r-project.org/web/packages/sampleSelection/index.html{sampleSelection
    ) or double selection models are inappropriate for this class of selection problems. To see this, note that a simple first stage discrete choice model assumes that an observed match reveals match partners' preferences over each other. In a matching market, however, agents can only choose from the set of partners who would be willing to form a match with them and we do not observe the players' relevant choice sets.

    Do I need an instrumental variable to estimate the model?

    Short answer: No. Long answer: The characteristics of other agents in the market serve as the source of exogenous variation necessary to identify the model. The identifying exclusion restriction is that characteristics of all agents in the market affect the matching, i.e., who matches with whom, but it is only the characteristics of the match partners that affect the outcome of a particular match once it is formed. No additional instruments are required for identification (Sorensen, 2007).

    What are the main assumptions underlying the estimator?

    The approach has certain limitations rooted in its restrictive economic assumptions.

    1. The matching models arecomplete informationmodels. That is, agents are assumed to have a complete knowledge of the qualities of other market participants.
    2. The models arestatic equilibriummodels. This implies that (i) the observed matching must be an equilibrium, i.e., no two agents would prefer to leave their current partners in order to form a new match (definition of pairwise stability), and (ii) the equilibrium must be unique for the likelihood function of the model to be well defined (Bresnahan and Reiss, 1991).
    3. Uniqueness results can be obtained in two ways. First, as is common in the industrial organization literature, by imposing suitablepreference restrictions. A suitable restriction on agents' preferences that guarantees a unique equilibrium is alignment (Pycia, 2012). In a group formation model, (pairwise) preference alignment states that any two agents who belong to the same groups must prefer the same group over the other. Second, by choosing amarket assigmentbased on matching algorithms that produce a unique stable matching, such as the well-studied Gale and Shapley (1962) deferred acceptance algorithm.
    4. Finally, the models assumebivariate normalityof the errors in selection and outcome equation. If that assumption fails, the estimator is generally inconsistent and can provide misleading inference in small samples.

    How to cite this package
    { Whenever using this package, please cite as

    Klein, T. (2014). matchingMarkets: An R package for the analysis of stable matchings. R package version 0.1-1. }

    http://cran.r-project.org/web/packages/sampleSelection/index.html{sampleSelection}

    Work in progress
    {
    1. Extension of the estimator instabitto allow for$n \ge 2$groups per market for the group formation problem. Currently, it supports$n \ge 2$groups per market for the roommates problem only.
    2. Extension of the estimator in thestabitfunction to allow for two-sided matching data from the college admissions problem. Currently, only one-sided matching data from the group formation and stable roommates problem is supported. % \item S3 methods for functions \code{stabit} and \code{mfx}. At least \code{print} and \code{summary}. % \item In \code{stabit} function the arguments "simulation" and "NTU" are redundant. Replace with \code{simulation} options \code{"TU"; "NTU"; "random"; "none"}. % \item Add more consistency checks.
    }

    package

    References

    Bresnahan, T. and Reiss, P. (1991). Empirical models of discrete games. Journal of Econometrics, 48(1-2):57--81.

    Gale, D. and Shapley, L.S. (1962). College admissions and the stability of marriage. The American Mathematical Monthly, 69(1):9--15.

    Heckman, J. (1979). Sample selection bias as a specification error. Econometrica, 47(1):153--161.

    Pycia, M. (2012). Stability and preference alignment in matching and coalition formation. Econometrica, 80(1):323--362.

    Sorensen, M. (2007). How smart is smart money? A two-sided matching model of venture capital. The Journal of Finance, 62(6):2725--2762.