Learn R Programming

matchingMarkets (version 0.3-1)

mfx: Marginal effects for probit and matching models

Description

Marginal effects from regression coefficients for probit and matching models.

Usage

mfx(m, toLatex = FALSE)

Arguments

m
an object returned from functions stabit or stabit2.
toLatex
logical: if TRUE the result tables are printed in Latex format. The default setting is FALSE.

References

Klein, T. (2015a). Does Anti-Diversification Pay? A One-Sided Matching Model of Microcredit. Cambridge Working Papers in Economics, #1521.

Examples

Run this code
## 1. load results from Klein (2015a)
 data(klein15a)

## 2. apply mfx function and print results
 mfx(m=klein15a)

Run the code above in your browser using DataLab