Learn R Programming

matchingMarkets (version 0.3-1)

stabsim: Simulate individual-level data for one-sided matching markets

Description

Simulate individual-level data for one-sided matching markets.

Usage

stabsim(m, ind, seed = 123, singles = NULL, gpm = 2)

Arguments

m
integer indicating the number of markets to be simulated.
ind
integer (or vector) indicating the number of individuals per group.
seed
integer setting the state for random number generation. Defaults to set.seed(123).
singles
integer giving the number of one-group markets.
gpm
integer giving the number of groups per market.

Value

stabsim returns a data frame with the randomly generated variables mimicking those in dataset baac00. .

Examples

Run this code
## Coalitions [gpm := 2 !]
## Simulate one-sided matching data for 4 markets (m=4) with 2 groups
## per market (gpm=2) and 2 to 4 individuals per group (ind=2:4)
 idata <- stabsim(m=4, ind=2:4, seed=124, singles=2, gpm=2)  

## Rommmates [ind := 2 !]
## Simulate one-sided matching data for 3 markets (m=3) with 3 groups
## per market (gpm=3) and 2 individuals per group (ind=2)
 idata <- stabsim(m=3, ind=2, seed=124, gpm=3)

Run the code above in your browser using DataLab