matchingMarkets package contains R, C++ and Java code for stable matching
algorithms and the estimation of structural models that correct for the sample selection bias of
observed outcomes in matching markets.Matching is concerned with who transacts with whom, and how. For example, who works at which job, which students go to which school, who forms a workgroup with whom, and so on.
The empirical analysis of matching markets is naturally subject to sample selection problems. If agents match assortatively on characteristics unobserved to the analyst but correlated with both the exogenous variable and the outcome of interest, regression estimates will generally be biased.
The matchingMarkets package comprises
stabit
and stabit2 correct for the selection bias from endogenous matching. The current package version provides solutions for two commonly observed matching processes: (i) the group formation problem with fixed group sizes and (ii) the college admissions problem. These processes determine which matches are observed -- and which are not -- and this is a sample selection problem.
mfx
computes marginal effects from coefficients in binary outcome and selection equations
and khb implements the Karlson-Holm-Breen test for confounding due to sample selection.
hri: A constraint model (Posser, 2014)
for the stable marriage and
college admissions problem, a.k.a. hospital/residents
problem (see Gale and Shapley, 1962). sri: A constraint model for the
stable roommates problem (see Gusfield and
Irving, 1989).
ttc: The top-trading-cycles algorithm for the
housing market problem. These can be used to obtain
stable matchings from simulated or real preference data (see Shapley and Scarf, 1974).
baac00 dataset from borrowing groups in Thailands largest agricultural lending program, the package provides functions stabsim and stabsim2 to simulate one's own data from one-sided and two-sided matching markets.
sampleSelection) or double selection models are
inappropriate for this class of selection problems. To see this, note that
a simple first stage discrete choice model assumes that an observed match
reveals match partners' preferences over each other. In a matching market,
however, agents can only choose from the set of partners who would be
willing to form a match with them and we do not observe the players'
relevant choice sets. Gale, D. and Shapley, L.S. (1962). College admissions and the stability of marriage. The American Mathematical Monthly, 69(1):9--15.
Gusfield, D.M. and R.W. Irving (1989). The stable marriage problem: Structure and algorithms, MIT Press.
Heckman, J. (1979). Sample selection bias as a specification error. Econometrica, 47(1):153--161.
Prosser, P. (2014). Stable Roommates and Constraint Programming. Lecture Notes in Computer Science, CPAIOR 2014 Edition. Springer International Publishing, 8451: 15--28.
Pycia, M. (2012). Stability and preference alignment in matching and coalition formation. Econometrica, 80(1):323--362. Shapley, L. and H. Scarf (1974). On cores and indivisibility. Journal of Mathematical Economics, 1(1):23--37.
Sorensen, M. (2007). How smart is smart money? A two-sided matching model of venture capital. The Journal of Finance, 62(6):2725--2762.