matchingMarkets package contains Rand C++ code for the estimation
of structural models that correct for the sample selection bias of observed outcomes in
matching markets.Matching is concerned with who transacts with whom, and how. For example, who works at which job, which students go to which school, who forms a workgroup with whom, and so on.
The empirical analysis of matching markets is naturally subject to sample selection problems. If agents match assortatively on characteristics unobserved to the analyst but correlated with both the exogenous variable and the outcome of interest, regression estimates will generally be biased.
The matchingMarkets package comprises
stabitcorrect for the selection bias from endogenous matching. The current package version provides solutions for two commonly observed matching processes: (i) thegroup formation problemwith fixed group sizes and (ii) theroommates problemwith transferable utility. Work on (iii) the college admissions problem is still in progress. These processes determine which matches are observed -- and which are not -- and this is a sample selection problem.
mfxcomputes marginal effects from coefficients in binary outcome and selection equations
andkhbimplements the Karlson-Holm-Breen test for confounding due to sample selection.stabitfunction has an argumentmethod="model.frame"that returns a design matrix based on pre-specified transformations to generate counterfactual matches.daa) forttc) forplp) for thebaac00dataset from borrowing groups in Thailands largest agricultural lending program, the package provides functions to simulate one's own data from matching markets.stabsimgenerates individual-level data and thestabitfunction has an argumentsimulationwhich generates group-level data and determines which groups are observed in equilibrium based on an underlying linear stochastic model.sampleSelection
Short answer: No. Long answer: The characteristics of other agents in the market serve as the source of exogenous variation necessary to identify the model. The identifying exclusion restriction is that characteristics of all agents in the market affect the matching, i.e., who matches with whom, but it is only the characteristics of the match partners that affect the outcome of a particular match once it is formed. No additional instruments are required for identification (Sorensen, 2007).
The approach has certain limitations rooted in its restrictive economic assumptions.
Klein, T. (2014). matchingMarkets: An R package for the analysis of stable matchings. R package version 0.1-1. }
stabitto allow for$n \ge 2$groups per market for the group formation problem. Currently, it supports$n \ge 2$groups per market for the roommates problem only.stabitfunction to allow for two-sided matching data from the college admissions problem. Currently, only one-sided matching data from the group formation and stable roommates problem is supported.
% \item S3 methods for functions \code{stabit} and \code{mfx}. At least \code{print} and \code{summary}.
% \item In \code{stabit} function the arguments "simulation" and "NTU" are redundant. Replace with \code{simulation} options \code{"TU"; "NTU"; "random"; "none"}.
% \item Add more consistency checks.Gale, D. and Shapley, L.S. (1962). College admissions and the stability of marriage. The American Mathematical Monthly, 69(1):9--15.
Heckman, J. (1979). Sample selection bias as a specification error. Econometrica, 47(1):153--161.
Pycia, M. (2012). Stability and preference alignment in matching and coalition formation. Econometrica, 80(1):323--362.
Sorensen, M. (2007). How smart is smart money? A two-sided matching model of venture capital. The Journal of Finance, 62(6):2725--2762.