Learn R Programming

matchingMarkets (version 0.1-1)

mfx: Marginal effects for probit and matching models

Description

Marginal effects from regression coefficients for probit and matching models.

Usage

mfx(m, toLatex = FALSE)

Arguments

m
an object returned from function stabit.
toLatex
logical: if TRUE the result tables are printed in Latex format. The default setting is FALSE.

Examples

Run this code
## 1. Read model results from Klein (2014), Table 5
## filepath <- system.file("scripts/TK_gibbsiter_ntu.mat", package="matchingMarkets")

## 2. Apply mfx function and print results
## mfx(m=filepath)

Run the code above in your browser using DataLab